==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/group___assimp_codec.js <==
var group___assimp_codec =
[
    [ "Ogre::AssimpLoader", "class_ogre_1_1_assimp_loader.html", [
      [ "Options", "struct_ogre_1_1_assimp_loader_1_1_options.html", [
        [ "Options", "struct_ogre_1_1_assimp_loader_1_1_options.html#af2b576ff086308c967bb17d5c17dc6ca", null ],
        [ "animationSpeedModifier", "struct_ogre_1_1_assimp_loader_1_1_options.html#acc8cd921e5135f7f10d491fa62a599cb", null ],
        [ "params", "struct_ogre_1_1_assimp_loader_1_1_options.html#a3654457ec5d49cbdc25879b2501a6fc0", null ],
        [ "customAnimationName", "struct_ogre_1_1_assimp_loader_1_1_options.html#aefa125d89ab9dd1848c040eede506639", null ],
        [ "maxEdgeAngle", "struct_ogre_1_1_assimp_loader_1_1_options.html#aca4f3631d2487ccf953f5a81c874add2", null ]
      ] ],
      [ "LoaderParams", "class_ogre_1_1_assimp_loader.html#aac26adf7ac4b5dfd6099ef96fbf0503d", [
        [ "LP_CUT_ANIMATION_WHERE_NO_FURTHER_CHANGE", "class_ogre_1_1_assimp_loader.html#aac26adf7ac4b5dfd6099ef96fbf0503da0b170287e9534810548515519defa0aa", null ],
        [ "LP_QUIET_MODE", "class_ogre_1_1_assimp_loader.html#aac26adf7ac4b5dfd6099ef96fbf0503da9199e4c8b35bf54e0f477f131c1b7b12", null ]
      ] ],
      [ "AssimpLoader", "class_ogre_1_1_assimp_loader.html#a51fb2bc0c2e81a42355ced11ee1bd135", null ],
      [ "~AssimpLoader", "class_ogre_1_1_assimp_loader.html#ac338ba2acd925061e0c0e52ca21c0270", null ],
      [ "load", "class_ogre_1_1_assimp_loader.html#a4c2dd8325ed123d2a36a2f4e591d8214", null ],
      [ "load", "class_ogre_1_1_assimp_loader.html#ae47d65ea0ddfe43c67f55a6185a44cc8", null ]
    ] ],
    [ "Ogre::AssimpPlugin", "class_ogre_1_1_assimp_plugin.html", [
      [ "getName", "class_ogre_1_1_assimp_plugin.html#a11767557894a27c62e7c3fead3d17a5c", null ],
      [ "install", "class_ogre_1_1_assimp_plugin.html#a129a0c5dd466264c2934a756f46a56ba", null ],
      [ "uninstall", "class_ogre_1_1_assimp_plugin.html#af486ed2c8b7b39d3aff3830a4af9b87a", null ],
      [ "initialise", "class_ogre_1_1_assimp_plugin.html#a6d0b6f4e4f6214f8941f14ca03919837", null ],
      [ "shutdown", "class_ogre_1_1_assimp_plugin.html#ad7d94128e3c993c45077909c5638e589", null ]
    ] ]
];

==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/group___assimp_codec.js <==
var group___assimp_codec =
[
    [ "Ogre::AssimpLoader", "class_ogre_1_1_assimp_loader.html", [
      [ "Options", "struct_ogre_1_1_assimp_loader_1_1_options.html", [
        [ "Options", "struct_ogre_1_1_assimp_loader_1_1_options.html#af2b576ff086308c967bb17d5c17dc6ca", null ],
        [ "animationSpeedModifier", "struct_ogre_1_1_assimp_loader_1_1_options.html#acc8cd921e5135f7f10d491fa62a599cb", null ],
        [ "params", "struct_ogre_1_1_assimp_loader_1_1_options.html#a3654457ec5d49cbdc25879b2501a6fc0", null ],
        [ "postProcessSteps", "struct_ogre_1_1_assimp_loader_1_1_options.html#a58414e94f4eb1adaecdbf1a6acd74d96", null ],
        [ "customAnimationName", "struct_ogre_1_1_assimp_loader_1_1_options.html#aefa125d89ab9dd1848c040eede506639", null ],
        [ "maxEdgeAngle", "struct_ogre_1_1_assimp_loader_1_1_options.html#aca4f3631d2487ccf953f5a81c874add2", null ]
      ] ],
      [ "LoaderParams", "class_ogre_1_1_assimp_loader.html#aac26adf7ac4b5dfd6099ef96fbf0503d", [
        [ "LP_CUT_ANIMATION_WHERE_NO_FURTHER_CHANGE", "class_ogre_1_1_assimp_loader.html#aac26adf7ac4b5dfd6099ef96fbf0503da0b170287e9534810548515519defa0aa", null ],
        [ "LP_QUIET_MODE", "class_ogre_1_1_assimp_loader.html#aac26adf7ac4b5dfd6099ef96fbf0503da9199e4c8b35bf54e0f477f131c1b7b12", null ]
      ] ],
      [ "AssimpLoader", "class_ogre_1_1_assimp_loader.html#a51fb2bc0c2e81a42355ced11ee1bd135", null ],
      [ "~AssimpLoader", "class_ogre_1_1_assimp_loader.html#ac338ba2acd925061e0c0e52ca21c0270", null ],
      [ "load", "class_ogre_1_1_assimp_loader.html#a4c2dd8325ed123d2a36a2f4e591d8214", null ],
      [ "load", "class_ogre_1_1_assimp_loader.html#ae47d65ea0ddfe43c67f55a6185a44cc8", null ]
    ] ],
    [ "Ogre::AssimpPlugin", "class_ogre_1_1_assimp_plugin.html", [
      [ "getName", "class_ogre_1_1_assimp_plugin.html#a11767557894a27c62e7c3fead3d17a5c", null ],
      [ "install", "class_ogre_1_1_assimp_plugin.html#a129a0c5dd466264c2934a756f46a56ba", null ],
      [ "uninstall", "class_ogre_1_1_assimp_plugin.html#af486ed2c8b7b39d3aff3830a4af9b87a", null ],
      [ "initialise", "class_ogre_1_1_assimp_plugin.html#a6d0b6f4e4f6214f8941f14ca03919837", null ],
      [ "shutdown", "class_ogre_1_1_assimp_plugin.html#ad7d94128e3c993c45077909c5638e589", null ]
    ] ]
];
